# SDP Neural Network Verification

This directory provides a standalone implementation of the SDP-FO algorithm from [Dathathri et al 2020](https://arxiv.org/abs/2010.11645).

If you find this code useful, we would appreciate if you cite our paper:

```
@article{dathathri2020sdpfo,
  title={Enabling certification of verification-agnostic networks via memory-efficient semidefinite programming},
  author={Dathathri, Sumanth and Dvijotham, Krishnamurthy and Kurakin, Alexey and Raghunathan, Aditi and Uesato, Jonathan and Bunel, Rudy and Shankar, Shreya and Steinhardt, Jacob and Goodfellow, Ian and Liang, Percy and Kohli, Pushmeet},
  journal={NeurIPS},
  year={2020}
}
```
